@@ -65,6 +65,7 @@
 # 03-Jan-2023  bv Include _pdbx_database_status.status_code_nmr_data for experimental data availability
 # 26-Jan-2023 dwp Populate or update pdbx_database_status attributes for CSMs to make ready for RELease
 # 21-Feb-2023  bv Update '__filterExperimentalResolution' method to handle experimental resolutions properly (see RO-3559)
+# 01-Feb-2024  bv Update method 'addEntryInfo' to support deuterated water molecule count
 #
 ##
 """
@@ -960,7 +961,7 @@ class DictMethodEntryHelper(object):
             # Various atom counts -
             #
             repModelId = repModelL[0]
-            numHeavyAtomsModel, numHydrogenAtomsModel, numAtomsTotal, numModelsTotal = self.__commonU.getDepositedAtomCounts(dataContainer, modelId=repModelId)
+            numHeavyAtomsModel, numHydrogenAtomsModel, numAtomsTotal, numModelsTotal, numDeuWatMolModel = self.__commonU.getDepositedAtomCounts(dataContainer, modelId=repModelId)
             #
             logger.debug("numAtomsTotal %d numHeavyAtomsModel %d numModelsTotal %d", numAtomsTotal, numHeavyAtomsModel, numModelsTotal)
             logger.debug("entity type atom counts %r", self.__commonU.getEntityTypeHeavyAtomCounts(dataContainer, modelId=repModelId))
@@ -971,6 +972,7 @@ class DictMethodEntryHelper(object):
                 cObj.setValue(numHeavyAtomsModel, "deposited_atom_count", 0)
                 cObj.setValue(numModelsTotal, "deposited_model_count", 0)
                 cObj.setValue(numHydrogenAtomsModel, "deposited_hydrogen_atom_count", 0)
+                cObj.setValue(numDeuWatMolModel, "deposited_deuterated_water_count", 0)
                 tCD = self.__commonU.getEntityTypeHeavyAtomCounts(dataContainer, modelId=repModelId)
                 wCount = tCD["water"] if tCD and "water" in tCD else 0
                 cObj.setValue(wCount, "deposited_solvent_atom_count", 0)
