@@ -5,6 +5,7 @@
 #
 # Update:
 #  16-Mar-2023 aae  Update configuration to use HERE and CACHE folder
+#   1-Jun-2023 aae  Don't back up resources to GitHub during cache update workflows
 #
 ##
 """
@@ -55,7 +56,7 @@ class NeighborInteractionWorkflow(object):
         self.__workPath = kwargs.get("workPath", HERE)
         self.__cachePath = kwargs.get("cachePath", os.path.join(self.__workPath, "CACHE"))
         #
-        self.__numProc = kwargs.get("numProc", 10)
+        self.__numProc = kwargs.get("numProc", 8)
         self.__chunkSize = kwargs.get("chunkSize", 10)
         self.__useCache = kwargs.get("useCache", False)
         #
@@ -76,7 +77,7 @@ class NeighborInteractionWorkflow(object):
         return ok
 
     def backup(self):
-        ok = self.__tiP.backup(self.__cfgOb, self.__configName, remotePrefix=self.__stashRemotePrefix, useStash=True, useGit=True)
+        ok = self.__tiP.backup(self.__cfgOb, self.__configName, remotePrefix=self.__stashRemotePrefix, useStash=True, useGit=False)
         return ok
 
     def restore(self, minCount=0):
